@@ -1,10 +1,10 @@
-from ..generic.general_methods import aedt_exception_handler, generate_unique_name
+from ..generic.general_methods import aedt_exception_handler
+from ..modeler.Circuit import ModelerNexxim
+from ..modules.PostProcessor import CircuitPostProcessor
+from ..modules.SolveSetup import SetupCircuit
 from .Analysis import Analysis
 from .Design import solutions_settings
-from ..modeler.Circuit import ModelerNexxim
-from ..modules.SetupTemplates import SetupKeys
-from ..modules.SolveSetup import SetupCircuit
-from ..modules.PostProcessor import CircuitPostProcessor
+
 
 class FieldAnalysisCircuit(Analysis):
     """FieldCircuitAnalysis class.
@@ -20,11 +20,33 @@ class FieldAnalysisCircuit(Analysis):
 
     """
 
-    def __init__(self, application, projectname, designname, solution_type, setup_name=None,
-                 specified_version=None, NG=False, AlwaysNew=False, release_on_exit=False, student_version=False):
+    def __init__(
+        self,
+        application,
+        projectname,
+        designname,
+        solution_type,
+        setup_name=None,
+        specified_version=None,
+        non_graphical=False,
+        new_desktop_session=False,
+        close_on_exit=False,
+        student_version=False,
+    ):
         self.solution_type = solution_type
-        Analysis.__init__(self, application, projectname, designname, solution_type, setup_name,
-                          specified_version, NG, AlwaysNew, release_on_exit, student_version)
+        Analysis.__init__(
+            self,
+            application,
+            projectname,
+            designname,
+            solution_type,
+            setup_name,
+            specified_version,
+            non_graphical,
+            new_desktop_session,
+            close_on_exit,
+            student_version,
+        )
         self._modeler = ModelerNexxim(self)
         self._modeler.primitives.init_padstacks()
         self._post = CircuitPostProcessor(self)
@@ -92,7 +114,7 @@ class FieldAnalysisCircuit(Analysis):
             BoundarySetup Module object
 
         """
-        ports = [p.replace('IPort@', '').split(';')[0] for p in self.modeler.oeditor.GetAllPorts()]
+        ports = [p.replace("IPort@", "").split(";")[0] for p in self.modeler.oeditor.GetAllPorts()]
         return ports
 
     @property
@@ -126,7 +148,7 @@ class FieldAnalysisCircuit(Analysis):
         return spar
 
     @aedt_exception_handler
-    def get_all_return_loss_list(self, excitation_names=[], excitation_name_prefix=''):
+    def get_all_return_loss_list(self, excitation_names=[], excitation_name_prefix=""):
         """Retrieve a list of all return losses for a list of exctitations.
 
         Parameters
@@ -148,15 +170,14 @@ class FieldAnalysisCircuit(Analysis):
         if not excitation_names:
             excitation_names = self.get_excitations_name
         if excitation_name_prefix:
-            excitation_names = [
-                i for i in excitation_names if excitation_name_prefix.lower() in i.lower()]
+            excitation_names = [i for i in excitation_names if excitation_name_prefix.lower() in i.lower()]
         spar = []
         for i in excitation_names:
             spar.append("S({},{})".format(i, i))
         return spar
 
     @aedt_exception_handler
-    def get_all_insertion_loss_list(self, trlist=[], reclist=[], tx_prefix='', rx_prefix=''):
+    def get_all_insertion_loss_list(self, trlist=[], reclist=[], tx_prefix="", rx_prefix=""):
         """Retrieve a list of all insertion losses from two lists of excitations (driver and receiver).
 
         Parameters
@@ -183,7 +204,7 @@ class FieldAnalysisCircuit(Analysis):
             trlist = [i for i in self.get_excitations_name if tx_prefix in i]
         if not reclist:
             reclist = [i for i in self.get_excitations_name if rx_prefix in i]
-        if len(trlist)!= len(reclist):
+        if len(trlist) != len(reclist):
             self._messenger.add_error_message("TX and RX should be same length lists")
             return False
         for i, j in zip(trlist, reclist):
@@ -213,14 +234,14 @@ class FieldAnalysisCircuit(Analysis):
         if not trlist:
             trlist = [i for i in self.get_excitations_name if tx_prefix in i]
         for i in trlist:
-            k = trlist.index(i)+1
+            k = trlist.index(i) + 1
             while k < len(trlist):
                 next.append("S({},{})".format(i, trlist[k]))
                 k += 1
         return next
 
     @aedt_exception_handler
-    def get_fext_xtalk_list(self, trlist=[], reclist=[], tx_prefix='', rx_prefix='', skip_same_index_couples=True):
+    def get_fext_xtalk_list(self, trlist=[], reclist=[], tx_prefix="", rx_prefix="", skip_same_index_couples=True):
         """Retrieve a list of all the far end XTalks from two lists of exctitations (driver and receiver).
 
         Parameters
@@ -255,7 +276,7 @@ class FieldAnalysisCircuit(Analysis):
             reclist = [i for i in self.get_excitations_name if rx_prefix in i]
         for i in trlist:
             for k in reclist:
-                if not skip_same_index_couples or reclist.index(k)!= trlist.index(i):
+                if not skip_same_index_couples or reclist.index(k) != trlist.index(i):
                     fext.append("S({},{})".format(i, k))
         return fext
 
