@@ -262,7 +262,7 @@ class DesignCache(object):
 
     Parameters
     ----------
-    parent: str
+    parent : str
         Name of the parent object.
 
     """
@@ -488,7 +488,7 @@ class Design(object):
     solution_type : str, optional
         Solution type to apply to the design. The default is
         ``None``, in which case the default type is applied.
-    specified_version: str, optional
+    specified_version : str, optional
         Version of AEDT to use. The default is ``None``, in which case
         the active version or latest installed version is used.
     NG : bool, optional
@@ -517,7 +517,7 @@ class Design(object):
 
     def __exit__(self, ex_type, ex_value, ex_traceback):
         if ex_type:
-            exception_to_desktop(self, ex_value, ex_traceback)
+            exception_to_desktop(ex_value, ex_traceback)
         if self.release_on_exit:
             self.release_desktop(self.close_on_exit, self.close_on_exit)
 
@@ -1153,7 +1153,8 @@ class Design(object):
 
     @aedt_exception_handler
     def add_info_message(self, message_text, message_type=None):
-        """Add a type 0 "Info" message to the active design level of the Message Manager tree.
+        """Add a type 0 "Info" message to either global, active project or active design
+        level of the Message Manager tree.
 
         Also add an info message to the logger if the handler is present.
 
@@ -1186,7 +1187,8 @@ class Design(object):
 
     @aedt_exception_handler
     def add_warning_message(self, message_text, message_type=None):
-        """Add a type 0 "Warning" message to the active design level of the Message Manager tree.
+        """Add a type 0 "Warning" message to either global, active project or active design
+        level of the Message Manager tree.
 
         Also add an info message to the logger if the handler is present.
 
@@ -1219,7 +1221,8 @@ class Design(object):
 
     @aedt_exception_handler
     def add_error_message(self, message_text, message_type=None):
-        """Add a type 0 "Error" message to the active design level of the Message Manager tree.
+        """Add a type 0 "Error" message to either global, active project or active design
+        level of the Message Manager tree.
 
         Also add an error message to the logger if the handler is present.
 
@@ -1261,6 +1264,120 @@ class Design(object):
         """
         return self._variable_manager
 
+    @aedt_exception_handler
+    def set_license_type(self, license_type="Pool"):
+        """Change the License Type between ``Pack`` and ``Pool``.
+
+        .. note::
+           The command returns ``True`` even if the Key is wrong due
+           to API limitation.
+
+        Parameters
+        ----------
+        license_type : str, optional
+            Set License Type between ``Pack`` and ``Pool``.
+
+        Returns
+        -------
+        bool
+        """
+        try:
+            self.odesktop.SetRegistryString("Desktop/Settings/ProjectOptions/HPCLicenseType", license_type)
+            return True
+        except:
+            return False
+
+    @aedt_exception_handler
+    def set_registry_key(self, key_full_name, key_value):
+        """Change a specific registry key to new value.
+
+        Parameters
+        ----------
+        key_full_name : str
+            Desktop Registry Key full name.
+        key_value : str, int
+            Desktop Registry Key value.
+        Returns
+        -------
+        bool
+        """
+        if isinstance(key_value, str):
+            try:
+                self.odesktop.SetRegistryString(key_full_name, key_value)
+                self._messenger.add_info_message("Key {} correctly changed.".format(key_full_name))
+                return True
+            except:
+                self._messenger.add_warning_message("Error setting up Key {}.".format(key_full_name))
+                return False
+        elif isinstance(key_value, int):
+            try:
+                self.odesktop.SetRegistryInt(key_full_name, key_value)
+                self._messenger.add_info_message("Key {} correctly changed.".format(key_full_name))
+                return True
+            except:
+                self._messenger.add_warning_message("Error setting up Key {}.".format(key_full_name))
+                return False
+        else:
+            self._messenger.add_warning_message("Key Value must be an int or str.")
+            return False
+
+    @aedt_exception_handler
+    def set_active_dso_config_name(self, product_name="HFSS", config_name="Local"):
+        """Change a specific registry key to new value.
+
+        Parameters
+        ----------
+        product_name : str
+            Name of the tool to which apply the active Configuration.
+        config_name : str
+            Name of configuration to apply.
+        Returns
+        -------
+        bool
+        """
+        try:
+            self.set_registry_key("Desktop/ActiveDSOConfigurations/{}".format(product_name), config_name)
+            self._messenger.add_info_message(
+                "Configuration Changed correctly to {} for {}.".format(config_name, product_name))
+            return True
+        except:
+            self._messenger.add_warning_message(
+                "Error Setting Up Configuration {} for {}.".format(config_name, product_name))
+            return False
+
+    @aedt_exception_handler
+    def set_registry_from_file(self, registry_file, make_active=True):
+        """Apply desktop Registry settings from acf file. A way to get an editable ACF file is to export a
+        configuration from Desktop UI, edit and reuse it.
+
+        Parameters
+        ----------
+        registry_file : str
+            Full path to acf file.
+        make_active : bool, optional
+            Set imported Configuration as active.
+
+        Returns
+        -------
+        bool
+        """
+        try:
+            self.odesktop.SetRegistryFromFile(registry_file)
+            if make_active:
+                with open(registry_file, 'r') as f:
+                    for line in f:
+                        stripped_line = line.strip()
+                        if "ConfigName" in stripped_line:
+                            config_name = stripped_line.split("=")
+                        elif "DesignType" in stripped_line:
+                            design_type = stripped_line.split("=")
+                            break
+                    if design_type and config_name:
+                        self.set_active_dso_config_name(design_type[1], config_name[1])
+            return True
+        except:
+            return False
+
     @aedt_exception_handler
     def _optimetrics_variable_args(
         self,
@@ -1669,9 +1786,9 @@ class Design(object):
 
         Parameters
         ----------
-        close_projects: bool, optional
+        close_projects : bool, optional
             Whether to close all projects. The default is ``True``.
-        close_desktop: bool, optional
+        close_desktop : bool, optional
             Whether to close the desktop after releasing it. The default is ``True``.
 
         Returns
@@ -1745,13 +1862,11 @@ class Design(object):
             ``True`` when successful, ``False`` when failed.
 
         """
-        legacy_project = self.project_name
+        if close_active_proj:
+            self.close_project(self.project_name)
         proj = self._desktop.OpenProject(project_file)
-
         if proj:
             self.__init__(projectname=proj.GetName(), designname=design_name)
-            if close_active_proj:
-                self._desktop.CloseProject(legacy_project)
             return True
         else:
             return False
@@ -1872,9 +1987,9 @@ class Design(object):
             List of X-axis values for the dataset.
         ylist : list
             List of Y-axis values for the dataset.
-        zylist : list, optional
+        zlist : list, optional
             List of Z-axis values for a 3D dataset only. The default is ``None``.
-        vylist : list, optional
+        vlist : list, optional
             List of V-axis values for a 3D dataset only. The default is ``None``.
         is_project_dataset : bool, optional
             Whether it is a project data set. The default is ``True``.
@@ -1905,6 +2020,7 @@ class Design(object):
             self.project_datasets[dsname] = ds
         else:
             self.design_datasets[dsname] = ds
+        self._messenger.add_info_message("Dataset {} created successfully.".format(dsname))
         return ds
 
     @aedt_exception_handler
@@ -2575,19 +2691,6 @@ class Design(object):
         self.__init__(self.project_name, self.design_name)
         return True
 
-    @aedt_exception_handler
-    def update_registry_from_file(self, filename):
-        """Update HPC options from a configuration file.
-
-        Parameters
-        ----------
-        filename : str
-            Full path and name of the configuration file, which can be an ACF or TXT file.
-
-        """
-        self._desktop.SetRegistryFromFile(r"%s" % os.path.abspath(filename))
-        return True
-
     @aedt_exception_handler
     def validate_simple(self, logfile=None):
         """Validate a design.
